@@ -23,8 +23,9 @@
 from __future__ import with_statement
 
 # This is also evaluated by the build scripts
-VERSION='0.9.0.2'
+VERSION='0.9.0.3'
 import logging
+import logging.handlers
 logging.basicConfig(level=logging.WARNING,
                     format='%(relativeCreated)6d %(levelname)10s %(name)-20s %(message)s // %(filename)s:%(lineno)s',
                     )
@@ -61,7 +62,6 @@ if len(argv) == 1:
 
 if '-v' in argv or '--remote' in argv:
     import colorer
-    import logging.handlers
     logging.getLogger('').setLevel(logging.DEBUG)
     logging.debug("Set log level to DEBUG")
     
@@ -198,10 +198,6 @@ class Core(gobject.GObject):
         
         
         
-        
-        
-        self.emit('settings-changed', self.settings, self)
-        self.emit('fieldnotes-changed')  
  
         if ('debug_log_to_http' in self.settings and self.settings['debug_log_to_http']) or '--remote' in argv:
             http_handler = logging.handlers.HTTPHandler("danielfett.de", "http://www.danielfett.de/files/collect.php")
@@ -209,6 +205,12 @@ class Core(gobject.GObject):
             logging.getLogger('').addHandler(buffering_handler)
             logging.getLogger('').setLevel(logging.DEBUG)
             logging.debug("Remote logging activated!")
+            # Now reset the setting to default
+            self.settings['debug_log_to_http'] = False
+        
+        
+        self.emit('settings-changed', self.settings, self)
+        self.emit('fieldnotes-changed')  
 
         if '--sim' in argv:
             self.gps_thread = gpsreader.FakeGpsReader(self)
